Package: Lahman
Type: Package
Title: Sean 'Lahman' Baseball Database
Version: 14.0-0
Date: 2026-02-11
Authors@R: c(person(given = "Michael", family = "Friendly", role="aut", email="friendly@yorku.ca"), 
        person(given ="Chris", family = "Dalzell", role=c("cre","aut"), email="cdalzell@gmail.com"),
        person(given ="Martin", family = "Monkman", role="aut"),
        person(given= "Dennis", family = "Murphy", role="aut"), 
        person(given ="Vanessa", family = "Foot", role="ctb"),
        person(given = "Justeena", family = "Zaki-Azat", role="ctb"),
        person(given = "Daniel J", family = "Eck", role="ctb", email="dje13@illinois.edu"),
        person(given = "Sean", family = "Lahman", role="cph")
        )
Author: Michael Friendly [aut],
  Chris Dalzell [cre, aut],
  Martin Monkman [aut],
  Dennis Murphy [aut],
  Vanessa Foot [ctb],
  Justeena Zaki-Azat [ctb],
  Daniel J Eck [ctb],
  Sean Lahman [cph]
Maintainer: Chris Dalzell <cdalzell@gmail.com>
Description: Provides the tables from the 'Sean Lahman Baseball Database' as
    a set of R data.frames. It uses the data on pitching, hitting and fielding
    performance and other tables from 1871 through 2024, as recorded in the 2025
    version of the database. Documentation examples show how many baseball
    questions can be investigated.
Language: en-US
Depends: R (>= 3.5.0)
Suggests: lattice, ggplot2, googleVis, data.table, vcd, reshape2,
        tidyr, knitr, rmarkdown, car, plyr, tidyverse
Imports: dplyr
Encoding: UTF-8
License: GPL
URL: https://cdalzell.github.io/Lahman/,
        https://CRAN.R-project.org/package=Lahman
LazyLoad: yes
LazyData: yes
LazyDataCompression: xz
BugReports: https://github.com/cdalzell/Lahman/issues
Repository: CRAN
NeedsCompilation: no
RoxygenNote: 7.3.3
VignetteBuilder: knitr
Packaged: 2026-02-12 00:01:36 UTC; DZ
Date/Publication: 2026-02-12 06:10:25 UTC
Built: R 4.6.0; ; 2026-04-26 12:35:08 UTC; unix
